@@ -5,8 +5,7 @@ from plone.restapi.services import Service
 
 
 class ContentDelete(Service):
-    """Deletes a content object.
-    """
+    """Deletes a content object."""
 
     def reply(self):
 
