@@ -76,6 +76,10 @@ class DefaultJsonSchemaProvider(object):
         if widget:
             schema["widget"] = widget
 
+        factory = self.get_factory()
+        if factory:
+            schema["factory"] = factory
+
         widget_options = self.get_widget_params()
         if widget_options:
             schema["widgetOptions"] = widget_options
@@ -89,6 +93,9 @@ class DefaultJsonSchemaProvider(object):
     def get_type(self):
         raise NotImplementedError
 
+    def get_factory(self):
+        return None
+
     def get_widget(self):
         return None
 
@@ -109,6 +116,9 @@ class BytesLineJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "string"
 
+    def get_factory(self):
+        return "Text line (String)"
+
 
 @adapter(ITextLine, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -126,6 +136,9 @@ class TextLineJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "string"
 
+    def get_factory(self):
+        return "Text line (String)"
+
 
 @adapter(IText, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -133,6 +146,9 @@ class TextJsonSchemaProvider(TextLineJsonSchemaProvider):
     def get_widget(self):
         return "textarea"
 
+    def get_factory(self):
+        return "Text"
+
 
 @adapter(IEmail, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -140,6 +156,9 @@ class EmailJsonSchemaProvider(TextLineJsonSchemaProvider):
     def get_widget(self):
         return "email"
 
+    def get_factory(self):
+        return "Email"
+
 
 @adapter(IPassword, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -147,6 +166,9 @@ class PasswordJsonSchemaProvider(TextLineJsonSchemaProvider):
     def get_widget(self):
         return "password"
 
+    def get_factory(self):
+        return "Password"
+
 
 @adapter(IURI, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -154,6 +176,9 @@ class URIJsonSchemaProvider(TextLineJsonSchemaProvider):
     def get_widget(self):
         return "url"
 
+    def get_factory(self):
+        return "URL"
+
 
 @adapter(IASCII, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -183,11 +208,13 @@ class FloatJsonSchemaProvider(DefaultJsonSchemaProvider):
 
         return info
 
+    def get_factory(self):
+        return "Floating-point number"
+
 
 @adapter(IDecimal, Interface, Interface)
 @implementer(IJsonSchemaProvider)
 class DecimalJsonSchemaProvider(FloatJsonSchemaProvider):
-
     pass
 
 
@@ -197,6 +224,9 @@ class IntegerJsonSchemaProvider(FloatJsonSchemaProvider):
     def get_type(self):
         return "integer"
 
+    def get_factory(self):
+        return "Integer"
+
 
 @adapter(IBool, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -204,6 +234,9 @@ class BoolJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "boolean"
 
+    def get_factory(self):
+        return "Yes/No"
+
 
 @adapter(ICollection, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -211,6 +244,20 @@ class CollectionJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "array"
 
+    def get_factory(self):
+        map = {
+            "RelationList": "Relation List",
+            "Set": "Multiple Choice",
+            "List": "List",
+            "Tuple": "Tuple",
+        }
+
+        for key, value in map.items():
+            if key in self.field.__repr__():
+                return value
+
+        return "Collection"
+
     def get_items(self):
         """Get items properties."""
         value_type_adapter = getMultiAdapter(
@@ -272,6 +319,14 @@ class ChoiceJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "string"
 
+    def get_factory(self):
+        map = {"RelationChoice": "Relation Choice", "Choice": "Choice"}
+
+        for key, value in map.items():
+            if key in self.field.__repr__():
+                return value
+        return "Choice"
+
     def additional(self):
         # Named global vocabulary
         vocab_name = getattr(self.field, "vocabularyName", None)
@@ -338,6 +393,12 @@ class ObjectJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_type(self):
         return "object"
 
+    def get_factory(self):
+        if self.field.schema.__name__ == "INamedBlobImage":
+            return "Image"
+        else:
+            return "File"
+
     def get_properties(self):
         if self.prefix:
             prefix = ".".join([self.prefix, self.field.__name__])
@@ -392,6 +453,9 @@ class RichTextJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_widget(self):
         return "richtext"
 
+    def get_factory(self):
+        return "Rich Text"
+
 
 @adapter(IDate, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -412,6 +476,9 @@ class DateJsonSchemaProvider(DefaultJsonSchemaProvider):
     def get_widget(self):
         return "date"
 
+    def get_factory(self):
+        return "Date"
+
 
 @adapter(IDatetime, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -419,6 +486,9 @@ class DatetimeJsonSchemaProvider(DateJsonSchemaProvider):
     def get_widget(self):
         return "datetime"
 
+    def get_factory(self):
+        return "Date/Time"
+
 
 @adapter(ITuple, Interface, Interface)
 @implementer(IJsonSchemaProvider)
@@ -434,3 +504,6 @@ class JSONFieldSchemaProvider(DefaultJsonSchemaProvider):
 
     def get_widget(self):
         return "json"
+
+    def get_factory(self):
+        return "JSONField"
